  {
      "requisiteStageRefIds": [""],
      "refId": "branch",
      "type": "jenkins",
      "comments": "This stage will apply a scaling policy if provided in <b>{{ data.app.environment }}</b>.",
      "name": "Attach Scaling Policy [{{ data.app.environment }}]",
      "failPipeline": true,
      "master": "JenkinsCI",
      "job": "pipes-scaling-policy",
      "parameters": {
        "PROJECT": "{{ data.app.group_name }}",
        "GIT_REPO": "{{ data.app.repo_name }}",
        "ENV": "{{ data.app.environment }}",
        "REGION": "{{ data.app.region }}"
        }
    }
