#   Foremast - Pipeline Tooling
#
#   Copyright 2018 Gogo, LLC
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
"""Overwriting the default output of warnings package."""
import warnings


def warning_format(message, category, *_, **__):
    """Warning format."""
    return '{}: {}\n'.format(category.__name__, message)


warnings.formatwarning = warning_format
warn_user = warnings.warn  # pylint: disable=invalid-name
